import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:kmobile/data/models/user.dart';
import 'package:material_symbols_icons/material_symbols_icons.dart';

class AccountInfoScreen extends StatefulWidget {
  final User user;

  const AccountInfoScreen({super.key, required this.user});

  @override
  State<AccountInfoScreen> createState() => _AccountInfoScreen();
}

class _AccountInfoScreen extends State<AccountInfoScreen> {
  @override
  Widget build(BuildContext context) {
    final user = widget.user;
    return Scaffold(
      appBar: AppBar(
        leading: IconButton(
          icon: const Icon(Symbols.arrow_back_ios_new),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
        title: const Text(
          'Account Info',
          style: TextStyle(color: Colors.black, fontWeight: FontWeight.w500),
        ),
        centerTitle: false,
        actions: [
          Padding(
            padding: const EdgeInsets.only(right: 10.0),
            child: CircleAvatar(
              backgroundColor: Colors.grey[200],
              radius: 20,
              child: SvgPicture.asset(
                'assets/images/avatar_male.svg',
                width: 40,
                height: 40,
                fit: BoxFit.cover,
              ),
            ),
          ),
        ],
      ),
      body: ListView(
        padding: const EdgeInsets.all(16.0),
        children: [
          InfoRow(title: 'Account Number', value: user.accountNo ?? 'N/A'),
          // InfoRow(title: 'Nominee Customer No', value: user.nomineeCustomerNo),
          // InfoRow(title: 'SMS Service', value: user.smsService),
          // InfoRow(title: 'Missed Call Service', value: user.missedCallService),
          InfoRow(title: 'Customer Number', value: user.cifNumber ?? 'N/A'),
          InfoRow(title: 'Product Name', value: user.productType ?? 'N/A'),
          // InfoRow(title: 'Account Opening Date', value: user.accountOpeningDate ?? 'N/A'),
          const InfoRow(title: 'Account Status', value: 'OPEN'),
          InfoRow(
              title: 'Available Balance',
              value: user.availableBalance ?? 'N/A'),
          InfoRow(
              title: 'Current Balance', value: user.currentBalance ?? 'N/A'),

          user.approvedAmount != null
              ? InfoRow(
                  title: 'Approved Amount', value: user.approvedAmount ?? 'N/A')
              : const SizedBox.shrink(),
        ],
      ),
    );
  }
}

class InfoRow extends StatelessWidget {
  final String title;
  final String value;

  const InfoRow({required this.title, required this.value, super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      margin: const EdgeInsets.symmetric(vertical: 8),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            title,
            style: const TextStyle(
              fontSize: 15,
              fontWeight: FontWeight.w500,
              color: Colors.black87,
            ),
          ),
          const SizedBox(height: 3),
          Text(
            value,
            style: const TextStyle(
              fontSize: 16,
              color: Colors.black,
            ),
          ),
        ],
      ),
    );
  }
}
