import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:kmobile/features/enquiry/screens/enquiry_screen.dart';
import 'package:material_symbols_icons/material_symbols_icons.dart';

class ChequeManagementScreen extends StatefulWidget {
  const ChequeManagementScreen({super.key});

  @override
  State<ChequeManagementScreen> createState() => _ChequeManagementScreen();
}

class _ChequeManagementScreen extends State<ChequeManagementScreen> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        leading: IconButton(
          icon: const Icon(Symbols.arrow_back_ios_new),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
        title: const Text(
          'Cheque Management',
          style: TextStyle(color: Colors.black, fontWeight: FontWeight.w500),
        ),
        centerTitle: false,
        actions: [
          Padding(
            padding: const EdgeInsets.only(right: 10.0),
            child: CircleAvatar(
              backgroundColor: Colors.grey[200],
              radius: 20,
              child: SvgPicture.asset(
                'assets/images/avatar_male.svg',
                width: 40,
                height: 40,
                fit: BoxFit.cover,
              ),
            ),
          ),
        ],
      ),
      body: ListView(
        children: [
          const SizedBox(height: 15),
          ChequeManagementTile(
            icon: Symbols.add,
            label: 'Request Checkbook',
            onTap: () {},
          ),
          const Divider(
            height: 1,
          ),
          ChequeManagementTile(
            icon: Symbols.data_alert,
            label: 'Enquiry',
            onTap: () {
              Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) => const EnquiryScreen()));
            },
          ),
          const Divider(
            height: 1,
          ),
          ChequeManagementTile(
            icon: Symbols.approval_delegation,
            label: 'Cheque Deposit',
            onTap: () {},
          ),
          const Divider(
            height: 1,
          ),
          ChequeManagementTile(
            icon: Symbols.front_hand,
            label: 'Stop Cheque',
            onTap: () {},
          ),
          const Divider(
            height: 1,
          ),
          ChequeManagementTile(
            icon: Symbols.cancel_presentation,
            label: 'Revoke Stop',
            onTap: () {},
          ),
          const Divider(
            height: 1,
          ),
          ChequeManagementTile(
            icon: Symbols.payments,
            label: 'Positive Pay',
            onTap: () {},
          ),
          const Divider(
            height: 1,
          ),
        ],
      ),
    );
  }
}

class ChequeManagementTile extends StatelessWidget {
  final IconData icon;
  final String label;
  final VoidCallback onTap;

  const ChequeManagementTile({
    super.key,
    required this.icon,
    required this.label,
    required this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    return ListTile(
      leading: Icon(icon),
      title: Text(label),
      trailing: const Icon(Symbols.arrow_right, size: 20),
      onTap: onTap,
    );
  }
}
